@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Bibus; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 #
 import wx
 import BIBbase, BIB, os, cPickle
@@ -26,6 +26,7 @@ class BibConfig(wx.Config):
 		self.createConfDir( appname )
 		self.setFilePath()
 		wx.Config.__init__(self,appname,localFilename = "%s.conf"%appname, style = wx.CONFIG_USE_RELATIVE_PATH )
+		
 					
 	def	createConfDir(self,app):
 		"""We create all the necessary configuration Directories if needed"""
@@ -41,10 +42,17 @@ class BibConfig(wx.Config):
 			os.mkdir( os.path.join( bibusConfDir, "Shortcuts") )
 		if not os.path.exists( os.path.join( bibusConfDir, "Databases") ):	# Slite databases
 			os.mkdir( os.path.join( bibusConfDir, "Databases") )
+		if not os.path.exists( os.path.join( bibusConfDir, "Import") ):	# personal Import filters
+			os.mkdir( os.path.join( bibusConfDir, "Import") )
+		if not os.path.exists( os.path.join( bibusConfDir, "Export") ):	# personal Export filters
+			os.mkdir( os.path.join( bibusConfDir, "Export") )
 		
 	def setFilePath(self):
 		# we have to set the path explicitly for wx.Python < 2.8.2
 		os.chdir( wx.StandardPaths.Get().GetUserDataDir() )
+		
+	def getFilePath(self):
+		return wx.StandardPaths.Get().GetUserDataDir()
 
 	def readConfig(self):
 		"""We set the variables in BIB module"""
@@ -53,7 +61,8 @@ class BibConfig(wx.Config):
 		if self.HasGroup('general'):
 			BIB.FIRST_START = self.ReadBool('/general/firststart')
 			BIB.CONFIG_VERSION = self.Read('/general/config_version')
-			BIB.WP = self.Read('/general/wp',BIB.WP)	# word processor connection type OOo/mswDoc
+			BIB.WP = self.Read('/general/wp',BIB.WP)	# word processor connection type OOo/mswDoc/LyX
+			BIB.TEXT_CLIPBOARD = self.Read('/general/text_clipboard',BIB.TEXT_CLIPBOARD)
 		if self.HasGroup('mysql'):
 			BIB.SOCKET = self.Read('/mysql/socket',BIB.SOCKET)
 			BIB.PORT = self.ReadInt('/mysql/port',BIB.PORT)
@@ -127,6 +136,8 @@ class BibConfig(wx.Config):
 			BIB.OO_HILIGHT = self.ReadBool('/OOo/hilight',BIB.OO_HILIGHT)
 			BIB.OO_AUTO_UPDATE = self.ReadBool('/OOo/auto_update',BIB.OO_AUTO_UPDATE)
 			BIB.OO_CREATE_BIB = self.ReadBool('/OOo/create_bib',BIB.OO_CREATE_BIB)
+		if self.HasGroup('Lyx'):	# LyX settings
+			BIB.LYX_PIPE = self.Read('/Lyx/lyx_pipe',BIB.LYX_PIPE)
 		if self.HasGroup('printer'):	# printer settings
 			if self.HasEntry('/printer/format'): BIB.PRINTER_FORMAT = eval(self.Read('/printer/format'))
 			if self.HasEntry('/printer/colors'): BIB.PRINTER_COLORS = eval(self.Read('/printer/colors'))
@@ -134,6 +145,13 @@ class BibConfig(wx.Config):
 			BIB.PRINTER_USE_OOo_FORMAT = self.ReadBool('/printer/use_ooo_format',BIB.PRINTER_USE_OOo_FORMAT)
 		if self.HasGroup('path'):	# path settings
 			BIB.FILES = self.Read('/path/files',BIB.FILES)
+			head, tail = os.path.split(BIB.FILES) # We need to ensure that there is no trailing / in the path
+			if not tail: BIB.FILES = head
+			BIB.MOVEAUTO = self.ReadBool('/path/moveauto',BIB.MOVEAUTO)
+		if self.HasGroup('pubmed'):	# pubmed settings
+			BIB.PUBMED = self.Read('/pubmed/pubmed',BIB.PUBMED)
+			BIB.PUBMEDVIEW = self.Read('/pubmed/pubmedview',BIB.PUBMEDVIEW)
+			if self.HasEntry('/pubmed/proxies'): BIB.PROXIES = eval(self.Read('/pubmed/proxies'))
 		# reading shortcut list from $HOME/.bibus/Shortcuts/
 		tmp = os.listdir( os.path.join( wx.StandardPaths.Get().GetUserDataDir(), "Shortcuts") )
 		if tmp: BIB.SHORTCUTS = tmp
@@ -154,6 +172,11 @@ class BibConfig(wx.Config):
 		elif self.HasEntry('wp'):
 			self.DeleteEntry('wp',False)
 		#
+		if BIBbase.TEXT_CLIPBOARD != BIB.TEXT_CLIPBOARD:
+			self.Write('text_clipboard',BIB.TEXT_CLIPBOARD)		# type of clipboard format (export filter name)
+		elif self.HasEntry('text_clipboard'):
+			self.DeleteEntry('text_clipboard',False)			
+		#
 		self.SetPath('/display')
 		if BIBbase.LIST_DISPLAY != BIB.LIST_DISPLAY:
 			self.Write('fields',repr(BIB.LIST_DISPLAY))		# Fields displayed in reflist wx.ListCtrl
@@ -434,6 +457,12 @@ class BibConfig(wx.Config):
 		else:
 			if self.HasEntry('create_bib'): self.DeleteEntry('create_bib',False)
 		#
+		self.SetPath('/Lyx')		# LyX settings
+		if BIBbase.LYX_PIPE != BIB.LYX_PIPE:
+			self.Write('lyx_pipe',BIB.LYX_PIPE)
+		else:
+			if self.HasEntry('lyx_pipe'): self.DeleteEntry('lyx_pipe',False)	
+		#
 		self.SetPath('/printer')		# printer settings
 		if BIBbase.PRINTER_FORMAT != BIB.PRINTER_FORMAT:
 			self.Write('format',repr(BIB.PRINTER_FORMAT))
@@ -461,6 +490,27 @@ class BibConfig(wx.Config):
 		else:
 			if self.HasEntry('files'): self.DeleteEntry('files',False)
 		#
+		if BIBbase.MOVEAUTO != BIB.MOVEAUTO:
+			self.WriteBool('moveauto',BIB.MOVEAUTO)
+		else:
+			if self.HasEntry('moveauto'): self.DeleteEntry('moveauto',False)
+		#
+		self.SetPath('/pubmed')	# pubmed settings
+		if BIBbase.PUBMED != BIB.PUBMED:
+			self.Write('pubmed',BIB.PUBMED)
+		else:
+			if self.HasEntry('pubmed'): self.DeleteEntry('pubmed',False)
+			
+		if BIBbase.PUBMEDVIEW != BIB.PUBMEDVIEW:
+			self.Write('pubmedview',BIB.PUBMEDVIEW)
+		else:
+			if self.HasEntry('pubmedview'): self.DeleteEntry('pubmedview',False)
+			
+		if BIBbase.PROXIES != BIB.PROXIES:
+			self.Write('proxies',repr(BIB.PROXIES))
+		else:
+			if self.HasEntry('proxies'): self.DeleteEntry('proxies',False)
+		#
 		self.Flush()	# save the config changes
 
 #---------------------- Shortcuts ----------------------------------------------
@@ -509,3 +559,4 @@ class BibConfig(wx.Config):
 		"""Return true if the username was already defined in the config"""
 		self.setFilePath()
 		return self.HasEntry('/%s/user'%dbType)
+		
