@@ -16,7 +16,7 @@
 # along with Bibus; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 #
-from bibOOo.CONST import JOURNAL
+from bibOOo.CONST import JOURNAL,JOURNAL_ALTERNATE
 
 def format(s,uselocale,f=0):
 	"""Return formatted journal according to choosed=n abbreviation/format
@@ -25,8 +25,8 @@ def format(s,uselocale,f=0):
 	f = 2 => abbreviation 3 (Default = Full = Journal of molecular biology)
 	"""
 	try:
-		if JOURNAL[s][f]:
-			return JOURNAL[s][f]
+		if JOURNAL[JOURNAL_ALTERNATE[s.upper()]][f]:
+			return JOURNAL[JOURNAL_ALTERNATE[s.upper()]][f]
 		else:
 			raise "empty journal"
 	except:
