@@ -33,7 +33,7 @@ import wx
 import time
 import BIB
 SUBSTR = 'SUBSTR'	# SUBSTRING keyword. 'SUBSTR' in SQLite and MySQL >= 4.1; 'SUBSTRING' in MySQL all versions
-TABLE_REF, TABLE_LINK, TABLE_KEY, TABLE_QUERY, TABLE_MODIF = "","","","","" # set in derived classes
+TABLE_REF, TABLE_LINK, TABLE_KEY, TABLE_QUERY, TABLE_MODIF, TABLE_FILE = "","","","","","" # set in derived classes
 
 class dbBib(object):
 	def __init__(self,parent=None,paramstyle='pyformat'):
@@ -42,6 +42,7 @@ class dbBib(object):
 		self.tableLink = ''
 		self.tableQuery = ''
 		self.tableModif = ''
+		self.tableFile = ''
 		self.parent=parent
 		self.dbConnection = None	# database connection
 		# parameter for DB API2 = "%s" for 'format' and 'pyformat'; "?" for "qmark"
@@ -75,7 +76,7 @@ class dbBib(object):
 		return (None,)
 
 
-	def createDatabase(self,db_name,tableref,tablekey,tablelink,tablequery,tablemodif):
+	def createDatabase(self,db_name,tableref,tablekey,tablelink,tablequery,tablemodif,tablefile):
 		return
 
 	def duplicateIdentifier(self,e):
@@ -103,9 +104,9 @@ class dbBib(object):
 		# we first test for duplicate references according to settings
 		if BIB.DUPLICATES_TEST:
 			if BIB.DUPLICATES_CASE:
-				tmpstr = """select Id from %s where """% self.tableRef + ' and '.join( ['%s = %s'%(field,self.param) for field in BIB.DUPLICATES] )
+				tmpstr = """select Id from %s where """% self.tableRef + ' and '.join( '%s = %s'%(field,self.param) for field in BIB.DUPLICATES )
 			else:
-				tmpstr = """select Id from %s where """% self.tableRef + ' and '.join( ['lower(%s) = lower(%s)'%(field,self.param) for field in BIB.DUPLICATES] )
+				tmpstr = """select Id from %s where """% self.tableRef + ' and '.join( 'lower(%s) = lower(%s)'%(field,self.param) for field in BIB.DUPLICATES )
 			self.dbCursor.execute( tmpstr, tuple([ref[BIB.BIBLIOGRAPHIC_FIELDS[field]] for field in BIB.DUPLICATES]) )
 			self.dbConnection.commit()
 			ref_id = self.dbCursor.fetchone()
@@ -243,14 +244,6 @@ class dbBib(object):
 		"""Return all the references tagged by user, ie all the refs except Trash"""
 		try:
 			if short:
-					# JOIN could be better for optimization but it is very slow with python-SQLite
-					# Subqueries are much faster. I will test later with new python-sqlite versions
-					#self.dbCursor.execute("""SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
-					#					JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
-					#					WHERE user=%s ORDER BY %s %s"""\
-					#					%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
-					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
-					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -259,12 +252,6 @@ class dbBib(object):
 										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
 										(user,))
 			else:
-					#self.dbCursor.execute("""SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
-					#					JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
-					#					WHERE user=%s ORDER BY %s %s"""\
-					#					%(','.join(('Id',)+collist),\
-					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
-					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -281,12 +268,6 @@ class dbBib(object):
 		"""Return all the refs non tagged by the current user => Trash"""
 		try:
 			if short:
-					#self.dbCursor.execute("""SELECT %s FROM %s LEFT JOIN \
-					#					(SELECT ref_Id FROM %s AS t1 JOIN %s AS t2 WHERE t1.key_Id=t2.key_Id AND user=%s) t3 \
-					#					ON Id=t3.ref_Id WHERE t3.ref_Id IS NULL ORDER BY %s %s"""\
-					#					% (','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
-					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
-					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id NOT IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -295,12 +276,6 @@ class dbBib(object):
 										self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
 										(user,))
 			else:
-					#self.dbCursor.execute("""SELECT %s FROM %s LEFT JOIN \
-					#					(SELECT ref_Id FROM %s AS t1 JOIN %s AS t2 WHERE t1.key_Id=t2.key_Id AND user=%s) t3 \
-					#					ON Id=t3.ref_Id WHERE t3.ref_Id IS NULL ORDER BY %s %s"""\
-					#					% (','.join(('Id',)+collist),\
-					#					self.tableRef, self.tableLink, self.tableKey,self.param,order,how),\
-					#					(user,))
 					self.dbCursor.execute("""SELECT %s FROM %s WHERE Id NOT IN \
 										(SELECT t1.ref_Id FROM %s AS t1 \
 										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -410,13 +385,7 @@ class dbBib(object):
 	def getAllRefSearch(self,user,searchStr,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
 		"""Return the references corresponding to the search 'searchStr' from all the refs belonging to current user"""
 		try:
-			#print searchStr.encode('latin1')
 			if not short:
-				#tmpstr = """SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
-				#			JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
-				#			WHERE user="%s" AND %s ORDER BY %s %s"""\
-				#			%(','.join(('Id',)+ collist),\
-				#			self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
 				tmpstr = """SELECT %s FROM %s WHERE Id IN \
 							(SELECT t1.ref_Id FROM %s AS t1 \
 							JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -424,11 +393,6 @@ class dbBib(object):
 							%(','.join(('Id',)+ collist),\
 							self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
 			else:
-				#tmpstr = """SELECT DISTINCT %s FROM %s JOIN %s AS t1 ON Id=t1.ref_Id \
-				#			JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
-				#			WHERE user="%s" AND %s ORDER BY %s %s"""\
-				#			%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT) for i in collist]),\
-				#			self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
 				tmpstr = """SELECT %s FROM %s WHERE Id IN \
 							(SELECT t1.ref_Id FROM %s AS t1 \
 							JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
@@ -440,6 +404,30 @@ class dbBib(object):
 		except Error,errorType:
 			self.showError("dbBibBase.getAllRefSearch: " + `errorType.args`)
 			return None
+			
+	def getTrashRefSearch(self,user,searchStr,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW,short=False):
+		"""Return the references corresponding to the search 'searchStr' from all the refs in the Trash of current user"""
+		try:
+			if short:
+					tmpstr = """SELECT %s FROM %s WHERE Id NOT IN \
+										(SELECT t1.ref_Id FROM %s AS t1 \
+										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+										WHERE user="%s") AND %s ORDER BY %s %s"""\
+										%(','.join(['Id']+["%s(%s,1,%s)"%(SUBSTR,i,BIB.LIST_SHORT)\
+										    for i in collist]),\
+										self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
+			else:
+					tmpstr = """SELECT %s FROM %s WHERE Id NOT IN \
+										(SELECT t1.ref_Id FROM %s AS t1 \
+										JOIN %s AS t2 ON t1.key_Id=t2.key_Id \
+										WHERE user="%s") AND %s ORDER BY %s %s"""\
+										%(','.join(('Id',)+collist),\
+										self.tableRef, self.tableLink, self.tableKey,user,searchStr,order,how)
+			self.dbCursor.execute(tmpstr.encode(BIB.ENCODING,BIB.ENC_ERRORS))
+			return self.dbCursor.fetchall()
+		except Error,errorType:
+			self.showError("dbBibBase.getTrashRefSearch: " + `errorType.args`)
+			return None
 
 	def getRefFromIdentifiers(self,Identifiers,collist=BIB.LIST_DISPLAY,order=BIB.LIST_ORDER,how=BIB.LIST_HOW):
 		"""Return the references corresponding to the list of Identifiers"""
@@ -658,6 +646,7 @@ class dbBib(object):
 			fields3 = self.getFields(self.tableLink)
 			fields4 = self.getFields(self.tableModif)
 			fields5 = self.getFields(self.tableQuery)
+			fields6 = self.getFields(self.tableFile)
 			#
 			for i in BIB.BIB_FIELDS:
 				if i not in fields: break
@@ -674,13 +663,20 @@ class dbBib(object):
 							for m in BIB.BIB_QUERY:
 								if m not in fields5: break
 							else:
-								return True
+								for n in BIB.BIB_FILE:
+									if n not in fields6: break
+								else:
+									return True
 				self.showError(_("Some needed fields are absent from the selected database/tables.\nContinue at your own risk"))
+				# Can SQlite 1.3/1.4 to 1.5 database conversion be invoked from elsewhere than the FirstStart Wizard?
+				# e.g. here, or as a separate utility
 				return False
 		else:	# grants == 'rr'
 			for i in BIB.BIB_FIELDS:
 				if i not in fields:
 					self.showError(_("Some needed fields are absent from the selected database/tables.\nContinue at your own risk"))
+					# Can SQlite 1.3/1.4 to 1.5 database conversion be invoked from elsewhere than the FirstStart Wizard?
+					# e.g. here, or as a separate utility
 					return False
 			return True
 
@@ -720,6 +716,14 @@ class dbBib(object):
 		except Error,errorType:
 			self.showError('dbBib.getAllModifs: '+`errorType.args`)
 			
+	def getAllFiles(self):
+		"""return all the files from the table table_file"""
+		try:
+			self.dbCursor.execute("""SELECT * FROM %s"""%self.tableFile)
+			return self.dbCursor.fetchall()
+		except Error,errorType:
+			self.showError('dbBib.getAllFiles: '+`errorType.args`)
+			
 	def dumpQuery(self,query):
 		self.__write(self.tableQuery,query)
 
@@ -767,6 +771,27 @@ class dbBib(object):
 			return self.dbCursor.fetchall()[0]
 		except:
 			return (_("Unknown"),0,_("Unknown"),0)
+			
+# Fulltext files. Table self.tableFile
+	def getFiles(self,ref_Id):
+		try:
+			self.dbCursor.execute("""SELECT path FROM %s WHERE ref_Id = %s""" %(self.tableFile,self.param), (ref_Id,))
+			tmp = self.dbCursor.fetchall()
+			if tmp:
+				return tuple([i[0] for i in tmp])
+			else:
+				return ()
+		except Error,errorType:
+			self.showError("dbBibBase.getFiles " + `errorType.args`)
+			
+	def setFiles(self,ref_Id,refs):
+		try:
+			self.dbCursor.execute("""DELETE FROM %s WHERE ref_Id = %s""" %(self.tableFile,self.param), (ref_Id,))
+			values = tuple([(ref_Id,ref) for ref in refs])
+			self.dbCursor.executemany("""INSERT INTO %s VALUES (%s,%s)""" %(self.tableFile,self.param,self.param),values)
+			self.dbConnection.commit()
+		except Error,errorType:
+			self.showError("dbBibBase.setFiles " + `errorType.args`)
 
 # Database cleanup
 	def emptyTrash(self):
@@ -793,12 +818,13 @@ class dbBib(object):
 	def checkDatabase(self):
 		error = False
 		# Checking that all the tables are present: 
-		tables = [table[0] for table in self.getTables()]
+		tables = self.getTables()
 		tablenames = {	self.tableRef:TABLE_REF,\
 						self.tableKey:TABLE_KEY,\
 						self.tableLink:TABLE_LINK,\
 						self.tableQuery:TABLE_QUERY,\
-						self.tableModif:TABLE_MODIF}
+						self.tableModif:TABLE_MODIF,\
+						self.tableFile:TABLE_FILE}
 		for table in tablenames.keys():
 			if table not in tables:
 				error = True
@@ -811,7 +837,7 @@ class dbBib(object):
 			self.showError( _("""Sorry, I can't fix this error."""))
 			error = True
 			return
-		# Checking for NULL Identifiers
+		# Checking for NULL Identifiers in bibref
 		self.dbCursor.execute("""SELECT Id FROM %s WHERE Identifier IS NULL"""%self.tableRef)
 		ids = self.dbCursor.fetchone()
 		if ids:
@@ -863,10 +889,17 @@ class dbBib(object):
 			error = True
 			ret = wx.MessageBox(_("The database contains wrong links in table_modif.\nShould I delete them ?"),_("Database error"),wx.YES_NO|wx.ICON_ERROR,self.parent)
 			if ret == wx.YES:
-				self.dbCursor.execute("""DELETE FROM %s WHERE ref_Id IN \
-											(SELECT ref_Id FROM %s LEFT JOIN %s ON ref_Id=Id WHERE Id IS NULL)"""
-											%(self.tableModif,self.tableModif,self.tableRef))
-				self.dbConnection.commit()
+				self.clean_tableModif()
+		# Checking for File links to non-existent references
+		self.dbCursor.execute("""SELECT ref_Id FROM %s LEFT JOIN %s \
+								ON ref_Id=Id WHERE Id IS NULL"""\
+								%(self.tableFile,self.tableRef))
+		ids = self.dbCursor.fetchone()
+		if ids:
+			error = True
+			ret = wx.MessageBox(_("The database contains Fulltext references pointing to non-existent references.\nShould I delete them ?"),_("Database error"),wx.YES_NO|wx.ICON_ERROR,self.parent)
+			if ret == wx.YES:
+				self.clean_tableFile()
 		# No error
 		if not error:
 			wx.MessageBox(_("Your database is a valid bibus database."),_("Database check"), wx.OK | wx.ICON_INFORMATION, self.parent)
